Welcome to the manageSF documentation!
======================================

ManageSF is a RESTful web service acting as a federating gateway to the components
of a Software Factory deployment.

.. toctree::
   :maxdepth: 2

   install
   restapi
   plugins
   resources
   contribute
